@@ -4,7 +4,7 @@ package App::ElasticSearch::Utilities;
 use strict;
 use warnings;
 
-our $VERSION = '7.6'; # VERSION
+our $VERSION = '7.7'; # VERSION
 
 our $_OPTIONS_PARSED;
 our %_GLOBALS = ();
@@ -14,6 +14,9 @@ our @_CONFIGS = (
     "$ENV{HOME}/.es-utils.yaml",
     "$ENV{HOME}/.es-utils.yml",
 );
+if( $ENV{HOME} ) {
+    push @_CONFIGS, map { "$ENV{HOME}/.es-utils.$_" } qw( yaml yml );
+}
 
 use CLI::Helpers qw(:all);
 use Getopt::Long qw(:config pass_through);
@@ -373,7 +376,6 @@ sub es_request {
         $index = '';
     }
 
-
     # Figure out if we're modifying things
     my $modification = $url eq '_search' && $options->{method} eq 'POST' ? 0
                      : $options->{method} ne 'GET';
@@ -884,7 +886,7 @@ App::ElasticSearch::Utilities - Utilities for Monitoring ElasticSearch
 
 =head1 VERSION
 
-version 7.6
+version 7.7
 
 =head1 SYNOPSIS
 
